@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class DarkRunApi(Base):
@@ -22,13 +23,21 @@ class DarkRunApi(Base):
         api_url = self.__get_api_url(dark_run_id)
         return self.api_get(api_url, params={})
 
-    def get_all_dark_runs_by_proposal_id_api(self, proposal_id):
+    def get_all_dark_runs_by_proposal_id_api(self, proposal_id,
+                                             page=DEF_PAGE,
+                                             page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'proposal_id': proposal_id})
+        return self.api_get(api_url, params={'proposal_id': proposal_id,
+                                             'page': page,
+                                             'page_size': page_size})
 
-    def get_all_dark_runs_by_detector_id_api(self, detector_id):
+    def get_all_dark_runs_by_detector_id_api(self, detector_id,
+                                             page=DEF_PAGE,
+                                             page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'detector_id': detector_id})
+        return self.api_get(api_url, params={'detector_id': detector_id,
+                                             'page': page,
+                                             'page_size': page_size})
 
     #
     # Private Methods
