@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class DataFileApi(Base):
@@ -28,9 +29,13 @@ class DataFileApi(Base):
                             params={'run_number': run_number,
                                     'proposal_number': proposal_number})
 
-    def get_all_data_files_by_data_group_id_api(self, data_group_id):
+    def get_all_data_files_by_data_group_id_api(self, data_group_id,
+                                                page=DEF_PAGE,
+                                                page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'data_group_id': data_group_id})
+        return self.api_get(api_url, params={'data_group_id': data_group_id,
+                                             'page': page,
+                                             'page_size': page_size})
 
     #
     # Private Methods
