@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class ExperimentApi(Base):
@@ -22,15 +23,21 @@ class ExperimentApi(Base):
         api_url = self.__get_api_url(experiment_id)
         return self.api_get(api_url, params={})
 
-    def get_all_experiments_by_name_and_proposal_id_api(self, name,
-                                                        proposal_id):
+    def get_all_experiments_by_name_and_proposal_id_api(
+            self, name, proposal_id,
+            page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
         return self.api_get(api_url,
-                            params={'name': name, 'proposal_id': proposal_id})
+                            params={'name': name, 'proposal_id': proposal_id,
+                                    'page': page, 'page_size': page_size})
 
-    def get_all_experiments_by_proposal_id_api(self, proposal_id):
+    def get_all_experiments_by_proposal_id_api(self, proposal_id,
+                                               page=DEF_PAGE,
+                                               page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'proposal_id': proposal_id})
+        return self.api_get(api_url, params={'proposal_id': proposal_id,
+                                             'page': page,
+                                             'page_size': page_size})
 
     #
     # Private Methods
