@@ -31,6 +31,9 @@ RUN_DATA_GROUP = 'run_data_group'
 SAMPLE = 'sample'
 SAMPLE_TYPE = 'sample_type'
 DARK_RUN = 'dark_run'
+TECHNIQUE = 'technique'
+INSTRUMENTS_TECHNIQUE = 'instruments_technique'
+PROPOSALS_TECHNIQUE = 'proposals_technique'
 
 ##########################################################################
 #
