@@ -7,21 +7,23 @@ from .apis import (
     DataSourceGroupApi, DataSourceGroupVersionApi, DataTypeApi, ExperimentApi,
     ExperimentTypeApi, InstrumentApi, ParameterApi, ParameterTypeApi,
     DarkRunApi,
-    ProposalApi, RepositoryApi, RunApi, SampleApi, UserApi)
+    ProposalApi, RepositoryApi, RunApi, SampleApi, UserApi,
+    TechniqueApi)
+from .common.config import DEF_PAGE, DEF_PAGE_SIZE
 # Import common classes
 from .common.util import Util
 from .modules import (
     DataFile, DataGroup, DataGroupRepository, DataGroupType,
     DataSourceGroup, DataSourceGroupVersion, Experiment,
     Instrument, Parameter, Proposal, Repository, Run, Sample)
-from .common.config import DEF_PAGE, DEF_PAGE_SIZE
 
 
 class MetadataClient(
     DataFileApi, DataGroupApi, DataGroupRepositoryApi, DataGroupTypeApi,
     DataSourceGroupApi, DataSourceGroupVersionApi, DataTypeApi, ExperimentApi,
     ExperimentTypeApi, InstrumentApi, ParameterApi, ParameterTypeApi,
-    DarkRunApi, ProposalApi, RepositoryApi, RunApi, SampleApi, UserApi
+    DarkRunApi, ProposalApi, RepositoryApi, RunApi, SampleApi, UserApi,
+    TechniqueApi
 ):
     def get_all_xfel_instruments(self, page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
         resp = Instrument.get_all_from_xfel(self, page, page_size)
