@@ -73,16 +73,22 @@ class DarkRun:
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_dark_runs_by_proposal_id(mdc_client, proposal_id):
-        response = mdc_client.get_all_dark_runs_by_proposal_id_api(proposal_id)
+    def get_all_dark_runs_by_proposal_id(mdc_client, proposal_id,
+                                         page=DEF_PAGE,
+                                         page_size=DEF_PAGE_SIZE):
+        response = mdc_client.get_all_dark_runs_by_proposal_id_api(
+            proposal_id, page, page_size)
 
         curr_method_name = inspect.currentframe().f_code.co_name
         Base.cal_debug(MODULE_NAME, curr_method_name, response)
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_dark_runs_by_detector_id(mdc_client, detector_id):
-        response = mdc_client.get_all_dark_runs_by_detector_id_api(detector_id)
+    def get_all_dark_runs_by_detector_id(mdc_client, detector_id,
+                                         page=DEF_PAGE,
+                                         page_size=DEF_PAGE_SIZE):
+        response = mdc_client.get_all_dark_runs_by_detector_id_api(
+            detector_id, page, page_size)
 
         curr_method_name = inspect.currentframe().f_code.co_name
         Base.cal_debug(MODULE_NAME, curr_method_name, response)
