@@ -197,12 +197,14 @@ class RunApiTest(ApiBase, unittest.TestCase):
         self.assert_not_eq_str(expect[field], expect_upd[field], field)
 
     def __get_all_entries_by_run_number_api(self, run_number, expect):
-        response = self.client_api.get_all_runs_by_run_number_api(run_number)
+        response = self.client_api.get_all_runs_by_run_number_api(
+            run_number, page=DEF_PAGE, page_size=10)
         receive = self.get_and_validate_all_entries_by_name(response)
         self.fields_validation(receive, expect)
 
     def __get_all_entries_by_proposal_number_api(self, prop_number, expect):
-        resp = self.client_api.get_all_runs_by_proposal_number_api(prop_number)
+        resp = self.client_api.get_all_runs_by_proposal_number_api(
+            prop_number, page=DEF_PAGE, page_size=10)
         receive = self.get_and_validate_all_entries_by_name(resp)
         self.fields_validation(receive, expect)
 
