@@ -160,7 +160,8 @@ class SampleApiTest(ApiBase, unittest.TestCase):
     def __get_all_entries_by_name_and_proposal_id_api(self,
                                                       name, proposal_id,
                                                       expect,
-                                                      page=1, page_size=100):
+                                                      page=DEF_PAGE,
+                                                      page_size=DEF_PAGE_SIZE):
         response = self.client_api.get_all_samples_by_name_and_proposal_id_api(
             name, proposal_id, page, page_size)
         receive = self.get_and_validate_all_entries_by_name(response)
