@@ -23,7 +23,8 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         )
 
     def test_get_data_group_types(self):
-        resp = self.mdc_client.get_all_data_group_types()
+        resp = self.mdc_client.get_all_data_group_types(page=DEF_PAGE,
+                                                        page_size=1)
 
         # Logging information
         logging.error('resp: {0}'.format(resp))
@@ -129,8 +130,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
     def test_get_proposal_experiments_with_errors(self):
         proposal_number = -99
-        resp = self.mdc_client.get_proposal_experiments(
-            proposal_number)
+        resp = self.mdc_client.get_proposal_experiments(proposal_number)
 
         # Logging information
         logging.error('resp: {0}'.format(resp))
@@ -214,7 +214,8 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
     def test_get_proposal_runs_first_page(self):
         proposal_number = 0
-        resp = self.mdc_client.get_proposal_runs(proposal_number, page=2, page_size=1)
+        resp = self.mdc_client.get_proposal_runs(proposal_number, page=2,
+                                                 page_size=1)
 
         # Logging information
         logging.error('resp: {0}'.format(resp))
@@ -240,7 +241,9 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
     def test_get_proposal_runs_second_page(self):
         proposal_number = 0
-        resp = self.mdc_client.get_proposal_runs(proposal_number, page=1, page_size=1)
+        resp = self.mdc_client.get_proposal_runs(proposal_number,
+                                                 page=DEF_PAGE,
+                                                 page_size=1)
 
         # Logging information
         logging.error('resp: {0}'.format(resp))
@@ -334,7 +337,9 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
     def test_get_proposal_samples_with_page_error_and_empty_data(self):
         proposal_number = 0
-        resp = self.mdc_client.get_proposal_samples(proposal_number, page=100, page_size=100)
+        resp = self.mdc_client.get_proposal_samples(proposal_number,
+                                                    page=100,
+                                                    page_size=3)
 
         # Logging information
         logging.error('resp: {0}'.format(resp))
@@ -370,11 +375,11 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assertEqual(prop_info['number'], 900061)
         self.assertEqual(prop_info['title'],
                          'DO NOT DELETE - CONTROLS TEST PROPOSAL 900061')
-        self.assertEqual(prop_info['abstract'], None)
+        self.assertEqual(prop_info['abstract'], "")
         self.assertEqual(prop_info['proposal_folder'], 'p900061')
         self.assertEqual(prop_info['def_proposal_path'],
                          '/gpfs/exfel/exp/SPB/200030/p900061/raw')
-        self.assertEqual(prop_info['doi'], '10.22003/XFEL.EU-DATA-900061-00')
+        self.assertEqual(prop_info['doi'], '10.0850/XFEL.EU-DATA-900061-00')
         self.assertEqual(prop_info['url'],
                          'https://www.xfel.eu/cas_robot_framework_test')
         self.assertEqual(prop_info['instrument_id'], 1)
@@ -411,7 +416,8 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         # Expected return:
         #
         self.assert_eq_val(resp['info'], 'Error getting proposal')
-        self.assert_eq_val(resp['app_info'], 'The proposal has no Samples defined yet in myMdC!')  # noqa
+        self.assert_eq_val(resp['app_info'],
+                           'The proposal has no Samples defined yet in myMdC!')  # noqa
         self.assert_eq_val(resp['success'], False)
         self.assert_eq_val(resp['data'], {})
 
