@@ -105,7 +105,9 @@ class DataGroupTest(ModuleBase, unittest.TestCase):
         # Get all by name
         #
         result3 = DataGroup.get_all_by_name(self.mdc_client,
-                                            data_group_name)
+                                            data_group_name,
+                                            page=DEF_PAGE,
+                                            page_size=DEF_PAGE_SIZE)
 
         # The result should be double because the same DataGroup was
         # successfully created twice
@@ -116,7 +118,9 @@ class DataGroupTest(ModuleBase, unittest.TestCase):
         # Get all by experiment_id
         #
         result31 = DataGroup.get_all_by_experiment_id(self.mdc_client,
-                                                      data_group_exp_id)
+                                                      data_group_exp_id,
+                                                      page=DEF_PAGE,
+                                                      page_size=DEF_PAGE_SIZE)
 
         # Note that position 0 of the List is already present in the
         # Application seeds file as an example
